==> dde-network-core_1.0.7.1.orig.tar.xz: dde-network-core-1.0.7.1/dss-network-plugin/translations/dss-network-plugin_nl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="nl" version="2.1">
<context>
    <name>Bubble</name>
    <message>
        <source>1 new message</source>
        <translation>1 nieuwe melding</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Connecting %1</source>
        <translation>Bezig met verbinden met ‘%1’</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>Verbonden met ‘%1’</translation>
    </message>
    <message>
        <source>%1 disconnected</source>
        <translation>Verbinding verbroken met ‘%1’</translation>
    </message>
    <message>
        <source>Unable to connect %1, please check your router or net cable.</source>
        <translation>Kan geen verbinding maken met ‘%1’ - controleer de router of netwerkkabel</translation>
    </message>
    <message>
        <source>Unable to connect %1, please keep closer to the wireless router</source>
        <translation>Kan geen verbinding maken met ‘%1’ - blijf in de buurt van de draadloze router</translation>
    </message>
    <message>
        <source>Connection failed, unable to connect %1, wrong password</source>
        <translation>Kan geen verbinding maken met ‘%1’: onjuist wachtwoord</translation>
    </message>
    <message>
        <source>Password is required to connect %1</source>
        <translation>Wachtwoord vereist om verbinding te maken met ‘%1’</translation>
    </message>
    <message>
        <source>The %1 802.11 WLAN network could not be found</source>
        <translation>Het 802.11 wlan-netwerk ‘%1’ is niet aangetroffen</translation>
    </message>
</context>
<context>
    <name>dss::module::NetworkModule</name>
    <message>
        <source>Wired Connection</source>
        <translation>Bekabelde verbinding</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetails</name>
    <message>
        <source>Hotspot</source>
        <translation>Hotspot</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation>Protocol</translation>
    </message>
    <message>
        <source>Security Type</source>
        <translation>Soort beveiliging</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>Band</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>Kanaal</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>Interface</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Netmasker</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>Primaire dns-server</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Voorvoegsel</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Snelheid</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDeviceRealize</name>
    <message>
        <source>Device disabled</source>
        <translation>Apparaat uitgeschakeld</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Verbonden, maar geen internettoegang</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Niet verbonden</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Geen netwerkkabel aangesloten</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Bezig met verbinden…</translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>Bezig met authenticeren…</translation>
    </message>
    <message>
        <source>Obtaining IP address</source>
        <translation>Bezig met verkrijgen van ip-adres…</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>Verbonden</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>Niet verbonden</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>IP-conflict</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>Mislukt</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation>Bezig met verkrijgen van adres…</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkProcesser</name>
    <message>
        <source>Wired Network</source>
        <translation>Bekabeld netwerk</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>Bekabeld netwerk: %1</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Draadloos netwerk</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>Draadloos netwerk: %1</translation>
    </message>
</context>
<context>
    <name>dde::networkplugin::NetworkPluginHelper</name>
    <message>
        <source>Device disabled</source>
        <translation>Apparaat uitgeschakeld</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Geen netwerkkabel aangesloten</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Niet verbonden</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Bezig met verbinden…</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Verbonden, maar geen internettoegang</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation>Verbinding mislukt</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>IP-conflict</translation>
    </message>
    <message>
        <source>Disable wired connection</source>
        <translation>Bekabelde verbinding uitschakelen</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>Bekabelde verbinding inschakelen</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>Draadloze verbinding uitschakelen</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>Draadloze verbinding inschakelen</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Netwerk uitschakelen</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>Netwerk inschakelen</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Netwerkinstellingen</translation>
    </message>
</context>
</TS>

==> dde-network-core_1.1.4.orig.tar.xz: dde-network-core-1.1.4/dss-network-plugin/translations/dss-network-plugin_nl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="nl">
<context>
    <name>Bubble</name>
    <message>
        <source>1 new message</source>
        <translation>1 nieuwe melding</translation>
    </message>
</context>
<context>
    <name>DeviceControllItem</name>
    <message>
        <source>Wireless Network</source>
        <translation>Draadloos netwerk</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Bekabeld netwerk</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Connecting %1</source>
        <translation>Bezig met verbinden met ‘%1’</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>Verbonden met ‘%1’</translation>
    </message>
    <message>
        <source>%1 disconnected</source>
        <translation>Verbinding verbroken met ‘%1’</translation>
    </message>
    <message>
        <source>Unable to connect %1, please check your router or net cable.</source>
        <translation>Kan geen verbinding maken met ‘%1’ - controleer de router of netwerkkabel</translation>
    </message>
    <message>
        <source>Unable to connect %1, please keep closer to the wireless router</source>
        <translation>Kan geen verbinding maken met ‘%1’ - blijf in de buurt van de draadloze router</translation>
    </message>
    <message>
        <source>Connection failed, unable to connect %1, wrong password</source>
        <translation>Kan geen verbinding maken met ‘%1’: onjuist wachtwoord</translation>
    </message>
    <message>
        <source>Password is required to connect %1</source>
        <translation>Wachtwoord vereist om verbinding te maken met ‘%1’</translation>
    </message>
    <message>
        <source>The %1 802.11 WLAN network could not be found</source>
        <translation>Het 802.11 wlan-netwerk ‘%1’ is niet aangetroffen</translation>
    </message>
</context>
<context>
    <name>WirelessItem</name>
    <message>
        <source>Connect to hidden network</source>
        <translation>Verbinden met verborgen netwerk</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Wachtwoord</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Annuleren</translation>
    </message>
    <message>
        <source>Connect</source>
        <comment>button</comment>
        <translation>Verbinden</translation>
    </message>
    <message>
        <source>Name (SSID)</source>
        <translation>Naam (SSID)</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetails</name>
    <message>
        <source>Hotspot</source>
        <translation>Hotspot</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation>Protocol</translation>
    </message>
    <message>
        <source>Security Type</source>
        <translation>Soort beveiliging</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>Kanaal</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>Band</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>Interface</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Netmasker</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>Primaire dns-server</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Voorvoegsel</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Snelheid</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDeviceRealize</name>
    <message>
        <source>Device disabled</source>
        <translation>Apparaat uitgeschakeld</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Verbonden, maar geen internettoegang</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Niet verbonden</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Geen netwerkkabel aangesloten</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Bezig met verbinden…</translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>Bezig met authenticeren…</translation>
    </message>
    <message>
        <source>Obtaining IP address</source>
        <translation>Bezig met verkrijgen van ip-adres…</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>Verbonden</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>Niet verbonden</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>IP-conflict</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>Mislukt</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation>Bezig met verkrijgen van adres…</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkProcesser</name>
    <message>
        <source>Wired Network</source>
        <translation>Bekabeld netwerk</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>Bekabeld netwerk: %1</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Draadloos netwerk</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>Draadloos netwerk: %1</translation>
    </message>
</context>
<context>
    <name>dde::networkplugin::NetworkPluginHelper</name>
    <message>
        <source>Device disabled</source>
        <translation>Apparaat uitgeschakeld</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Geen netwerkkabel aangesloten</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Niet verbonden</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Bezig met verbinden…</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Verbonden, maar geen internettoegang</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation>Verbinding mislukt</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>IP-conflict</translation>
    </message>
    <message>
        <source>Disable wired connection</source>
        <translation>Bekabelde verbinding uitschakelen</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>Bekabelde verbinding inschakelen</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>Draadloze verbinding uitschakelen</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>Draadloze verbinding inschakelen</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Netwerk uitschakelen</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>Netwerk inschakelen</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Netwerkinstellingen</translation>
    </message>
</context>
<context>
    <name>dss::module::NetworkModule</name>
    <message>
        <source>Wired Connection</source>
        <translation>Bekabelde verbinding</translation>
    </message>
</context>
</TS>
